@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative '../../puppet/util'
 require 'monitor'
 require_relative '../../puppet/parser/parser_factory'
@@ -22,7 +24,6 @@ end
 # logging functions. Logging functions are attached to the 'root' environment
 # when {Puppet::Parser::Functions.reset} is called.
 class Puppet::Node::Environment
-
   NO_MANIFEST = :no_manifest
 
   # The create() factory method should be used instead.
@@ -87,9 +88,9 @@ class Puppet::Node::Environment
   # @return [Puppet::Node::Environment]
   def override_with(env_params)
     return self.class.create(name,
-                      env_params[:modulepath] || modulepath,
-                      env_params[:manifest] || manifest,
-                      env_params[:config_version] || config_version)
+                             env_params[:modulepath] || modulepath,
+                             env_params[:manifest] || manifest,
+                             env_params[:config_version] || config_version)
   end
 
   # Creates a new Puppet::Node::Environment instance, overriding :manifest,
@@ -166,6 +167,44 @@ class Puppet::Node::Environment
   # @api private
   attr_reader :lock
 
+  # For use with versioned dirs
+  # our environment path may contain symlinks, while we want to resolve the
+  # path while reading the manifests we may want to report the resources as
+  # coming from the configured path.
+  attr_accessor :configured_path
+
+  # See :configured_path above
+  attr_accessor :resolved_path
+
+  # Ensure the path given is of the format we want in the catalog/report.
+  #
+  # Intended for use with versioned symlinked environments. If this
+  # environment is configured with "/etc/puppetlabs/code/environments/production"
+  # but the resolved path is
+  #
+  # "/opt/puppetlabs/server/puppetserver/filesync/client/puppet-code/production_abcdef1234"
+  #
+  # this changes the filepath
+  #
+  # "/opt/puppetlabs/server/puppetserver/filesync/client/puppet-code/production_abcdef1234/modules/foo/manifests/init.pp"
+  #
+  # to
+  #
+  # "/etc/puppetlabs/code/environments/production/modules/foo/manifests/init.pp"
+  def externalize_path(filepath)
+    paths_set        = configured_path && resolved_path
+    munging_possible = paths_set && configured_path != resolved_path
+    munging_desired  = munging_possible &&
+                         Puppet[:report_configured_environmentpath] &&
+                         filepath.to_s.start_with?(resolved_path)
+
+    if munging_desired
+      File.join(configured_path, filepath.delete_prefix(resolved_path))
+    else
+      filepath
+    end
+  end
+
   # Checks to make sure that this environment did not have a manifest set in
   # its original environment.conf if Puppet is configured with
   # +disable_per_environment_manifest+ set true.  If it did, the environment's
@@ -182,6 +221,7 @@ class Puppet::Node::Environment
   # @api private
   def conflicting_manifest_settings?
     return false if !Puppet[:disable_per_environment_manifest]
+
     original_manifest = configuration.raw_setting(:manifest)
     !original_manifest.nil? && !original_manifest.empty? && original_manifest != Puppet[:default_manifest]
   end
@@ -316,6 +356,7 @@ class Puppet::Node::Environment
           Puppet::FileSystem.basename_string(p)
         end.each do |name|
           next unless Puppet::Module.is_module_directory?(name, path)
+
           warn_about_mistaken_path(path, name)
           if not seen_modules[name]
             module_references << {:name => name, :path => File.join(path, name)}
@@ -414,13 +455,14 @@ class Puppet::Node::Environment
 
     modules.each do |mod|
       next unless mod.forge_name
+
       deps[mod.forge_name] ||= []
 
       mod.dependencies and mod.dependencies.each do |mod_dep|
         dep_name = mod_dep['name'].tr('-', '/')
         (deps[dep_name] ||= []) << {
-          'name'                => mod.forge_name,
-          'version'             => mod.version,
+          'name' => mod.forge_name,
+          'version' => mod.version,
           'version_requirement' => mod_dep['version_requirement']
         }
       end
@@ -511,8 +553,8 @@ class Puppet::Node::Environment
 
   # not private so it can be called in tests
   def self.extralibs()
-    if Puppet::Util.get_env('PUPPETLIB')
-      split_path(Puppet::Util.get_env('PUPPETLIB'))
+    if ENV['PUPPETLIB']
+      split_path(ENV['PUPPETLIB'])
     else
       []
     end
@@ -553,10 +595,12 @@ class Puppet::Node::Environment
       if file == NO_MANIFEST
         empty_parse_result
       elsif File.directory?(file)
-        parse_results = Puppet::FileSystem::PathPattern.absolute(File.join(file, '**/*.pp')).glob.sort.map do | file_to_parse |
+        # JRuby does not properly perform Dir.glob operations with wildcards, (see PUP-11788 and https://github.com/jruby/jruby/issues/7836).
+        # We sort the results because Dir.glob order is inconsistent in Ruby < 3 (see PUP-10115).
+        parse_results = Puppet::FileSystem::PathPattern.absolute(File.join(file, '**/*')).glob.select {|globbed_file| globbed_file.end_with?('.pp')}.sort.map do | file_to_parse |
           parser.file = file_to_parse
           parser.parse
-          end
+        end
         # Use a parser type specific merger to concatenate the results
         Puppet::Parser::AST::Hostclass.new('', :code => Puppet::Parser::ParserFactory.code_merger.concatenate(parse_results))
       else
