@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Puppet::Pops
 module Loader
 # =ModuleLoaders
@@ -19,9 +21,8 @@ module Loader
 # @api private
 #
 module ModuleLoaders
-
   # Wildcard module name for module loaders, makes loading possible from any namespace.
-  NAMESPACE_WILDCARD = '*'.freeze
+  NAMESPACE_WILDCARD = '*'
 
   # This is exactly the same as the #system_loader_from method, but the argument for path is changed to
   # location where pluginsync stores functions. It also accepts definitions in any namespace since pluginsync
@@ -29,12 +30,12 @@ module ModuleLoaders
   #
   def self.cached_loader_from(parent_loader, loaders)
     LibRootedFileBased.new(parent_loader,
-      loaders,
-      NAMESPACE_WILDCARD,
-      Puppet[:libdir],
-      'cached_puppet_lib',
-      [:func_4x, :func_3x, :datatype]
-    )
+                           loaders,
+                           NAMESPACE_WILDCARD,
+                           Puppet[:libdir],
+                           'cached_puppet_lib',
+                           [:func_4x, :func_3x, :datatype]
+                          )
   end
 
   def self.system_loader_from(parent_loader, loaders)
@@ -47,9 +48,9 @@ module ModuleLoaders
     LibRootedFileBased.new(parent_loader,
                            loaders,
                            nil,
-                           puppet_lib,   # may or may not have a 'lib' above 'puppet'
+                           puppet_lib, # may or may not have a 'lib' above 'puppet'
                            'puppet_system',
-                           [:func_4x, :func_3x, :datatype]   # only load ruby functions and types from "puppet"
+                           [:func_4x, :func_3x, :datatype] # only load ruby functions and types from "puppet"
                           )
   end
 
@@ -58,30 +59,30 @@ module ModuleLoaders
       EmptyLoader.new(parent_loader, ENVIRONMENT, loaders.environment)
     else
       FileBased.new(parent_loader,
-        loaders,
-        ENVIRONMENT,
-        env_path,
-        ENVIRONMENT
-      )
+                    loaders,
+                    ENVIRONMENT,
+                    env_path,
+                    ENVIRONMENT
+                   )
     end
   end
 
   def self.module_loader_from(parent_loader, loaders, module_name, module_path)
     ModuleLoaders::FileBased.new(parent_loader,
-                                                       loaders,
-                                                       module_name,
-                                                       module_path,
-                                                       module_name
-                                                       )
+                                 loaders,
+                                 module_name,
+                                 module_path,
+                                 module_name
+                                )
   end
 
   def self.pcore_resource_type_loader_from(parent_loader, loaders, environment_path)
     ModuleLoaders::FileBased.new(parent_loader,
-      loaders,
-      nil,
-      environment_path,
-      'pcore_resource_types'
-    )
+                                 loaders,
+                                 nil,
+                                 environment_path,
+                                 'pcore_resource_types'
+                                )
   end
 
   class EmptyLoader < BaseLoader
@@ -99,11 +100,9 @@ module ModuleLoaders
   end
 
   class AbstractPathBasedModuleLoader < BaseLoader
-
     # The name of the module, or nil, if this is a global "component", or "any module" if set to the `NAMESPACE_WILDCARD` (*)
     attr_reader :module_name
 
-
     # The path to the location of the module/component - semantics determined by subclass
     attr_reader :path
 
@@ -115,7 +114,7 @@ module ModuleLoaders
     # created a different way, this loader can be set explicitly by the loaders bootstrap logic.
     #
     # @api private
-    attr_accessor :private_loader
+    attr_writer :private_loader
 
     # Initialize a kind of ModuleLoader for one module
     # @param parent_loader [Loader] loader with higher priority
@@ -135,9 +134,10 @@ module ModuleLoaders
       @loaders = loaders
       @loadables = loadables
       unless (loadables - LOADABLE_KINDS).empty?
-        #TRANSLATORS 'loadables' is a variable containing loadable modules and should not be translated
+        # TRANSLATORS 'loadables' is a variable containing loadable modules and should not be translated
         raise ArgumentError, _('given loadables are not of supported loadable kind')
       end
+
       loaders.add_loader_by_name(self)
     end
 
@@ -152,6 +152,7 @@ module ModuleLoaders
           relative_paths(sp).each do |rp|
             tp = sp.typed_name(type, name_authority, rp, global ? nil : @module_name)
             next unless sp.valid_name?(tp)
+
             begin
               load_typed(tp) unless block_given? && !block.yield(tp)
             rescue StandardError => e
@@ -404,6 +405,7 @@ module ModuleLoaders
       is_global = global?
       smart_paths.effective_paths(typed_name.type).each do |sp|
         next unless sp.valid_name?(typed_name)
+
         origin = sp.effective_path(typed_name, is_global ? 0 : 1)
         unless origin.nil?
           if sp.fuzzy_matching?
@@ -430,7 +432,6 @@ module ModuleLoaders
   # @api private
   #
   class FileBased < AbstractPathBasedModuleLoader
-
     attr_reader :smart_paths
     attr_reader :path_index
 
