@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative '../puppet'
 require 'getoptlong'
 require_relative '../puppet/util/watched_file'
@@ -5,6 +7,7 @@ require_relative '../puppet/util/command_line/puppet_option_parser'
 require 'forwardable'
 require 'fileutils'
 require 'concurrent'
+require_relative 'concurrent/lock'
 
 # The class for handling configuration files.
 class Puppet::Settings
@@ -40,7 +43,6 @@ class Puppet::Settings
   # local reference for convenience
   PuppetOptionParser = Puppet::Util::CommandLine::PuppetOptionParser
 
-  attr_accessor :files
   attr_reader :timer
 
   # These are the settings that every app is required to specify; there are
@@ -50,20 +52,20 @@ class Puppet::Settings
   # The acceptable sections of the puppet.conf configuration file.
   ALLOWED_SECTION_NAMES = ['main', 'server', 'master', 'agent', 'user'].freeze
 
-  NONE = 'none'.freeze
+  NONE = 'none'
 
   # This method is intended for puppet internal use only; it is a convenience method that
   # returns reasonable application default settings values for a given run_mode.
   def self.app_defaults_for_run_mode(run_mode)
     {
-        :name      => run_mode.to_s,
-        :run_mode  => run_mode.name,
-        :confdir   => run_mode.conf_dir,
-        :codedir   => run_mode.code_dir,
-        :vardir    => run_mode.var_dir,
-        :publicdir => run_mode.public_dir,
-        :rundir    => run_mode.run_dir,
-        :logdir    => run_mode.log_dir,
+      :name => run_mode.to_s,
+      :run_mode => run_mode.name,
+      :confdir => run_mode.conf_dir,
+      :codedir => run_mode.code_dir,
+      :vardir => run_mode.var_dir,
+      :publicdir => run_mode.public_dir,
+      :rundir => run_mode.run_dir,
+      :logdir => run_mode.log_dir,
     }
   end
 
@@ -79,11 +81,11 @@ class Puppet::Settings
   end
 
   def self.hostname_fact()
-    Puppet.runtime[:facter].value :hostname
+    Puppet.runtime[:facter].value 'networking.hostname'
   end
 
   def self.domain_fact()
-    Puppet.runtime[:facter].value :domain
+    Puppet.runtime[:facter].value 'networking.domain'
   end
 
   def self.default_config_file_name
@@ -147,8 +149,23 @@ class Puppet::Settings
     @configuration_file = nil
 
     # And keep a per-environment cache
-    @cache = Concurrent::Hash.new { |hash, key| hash[key] = Concurrent::Hash.new }
-    @values = Concurrent::Hash.new { |hash, key| hash[key] = Concurrent::Hash.new }
+    # We can't use Concurrent::Map because we want to preserve insertion order
+    @cache_lock = Puppet::Concurrent::Lock.new
+    @cache = Concurrent::Hash.new do |hash, key|
+      @cache_lock.synchronize do
+        break hash[key] if hash.key?(key)
+
+        hash[key] = Concurrent::Hash.new
+      end
+    end
+    @values_lock = Puppet::Concurrent::Lock.new
+    @values = Concurrent::Hash.new do |hash, key|
+      @values_lock.synchronize do
+        break hash[key] if hash.key?(key)
+
+        hash[key] = Concurrent::Hash.new
+      end
+    end
 
     # The list of sections we've used.
     @used = []
@@ -202,7 +219,7 @@ class Puppet::Settings
   # understand, and add them to the passed option list.
   def addargs(options)
     # Add all of the settings as valid options.
-    self.each { |name, setting|
+    self.each { |_name, setting|
       setting.getopt_args.each { |args| options << args }
     }
 
@@ -213,7 +230,7 @@ class Puppet::Settings
   # understand, and add them to the passed option list.
   def optparse_addargs(options)
     # Add all of the settings as valid options.
-    self.each { |name, setting|
+    self.each { |_name, setting|
       options << setting.optparse_args
     }
 
@@ -264,7 +281,6 @@ class Puppet::Settings
   #
   # @api private
   def clear_environment_settings(environment)
-
     if environment.nil?
       return
     end
@@ -344,7 +360,7 @@ class Puppet::Settings
 
     # remove run_mode options from the arguments so that later parses don't think
     # it is an unknown option.
-    while option_index = args.index('--run_mode') do #rubocop:disable Lint/AssignmentInCondition
+    while option_index = args.index('--run_mode') do # rubocop:disable Lint/AssignmentInCondition
       args.delete_at option_index
       args.delete_at option_index
     end
@@ -368,7 +384,6 @@ class Puppet::Settings
     [opt, val]
   end
 
-
   def app_defaults_initialized?
     @app_defaults_initialized
   end
@@ -417,8 +432,8 @@ class Puppet::Settings
         setting.handle(self.value(setting.name))
       rescue InterpolationError => err
         raise InterpolationError, err.message, err.backtrace unless options[:ignore_interpolation_dependency_errors]
-        #swallow. We're not concerned if we can't call hooks because dependencies don't exist yet
-        #we'll get another chance after application defaults are initialized
+        # swallow. We're not concerned if we can't call hooks because dependencies don't exist yet
+        # we'll get another chance after application defaults are initialized
       end
     end
   end
@@ -510,7 +525,7 @@ class Puppet::Settings
     val = value(:configprint)
     if val == "all"
       hash = {}
-      each do |name, obj|
+      each do |name, _obj|
         val = value(name,env)
         val = val.inspect if val == ""
         hash[name] = val
@@ -521,7 +536,7 @@ class Puppet::Settings
     else
       val.split(/\s*,\s*/).sort.each do |v|
         if include?(v)
-          #if there is only one value, just print it for back compatibility
+          # if there is only one value, just print it for back compatibility
           if v == val
             puts value(val,env)
             break
@@ -549,6 +564,7 @@ class Puppet::Settings
   def print_configs
     return print_config_options if value(:configprint) != ""
     return generate_config if value(:genconfig)
+
     generate_manifest if value(:genmanifest)
   end
 
@@ -570,11 +586,11 @@ class Puppet::Settings
   def preferred_run_mode=(mode)
     mode = mode.to_s.downcase.intern
     raise ValidationError, "Invalid run mode '#{mode}'" unless [:server, :master, :agent, :user].include?(mode)
+
     @preferred_run_mode_name = mode
     # Changing the run mode has far-reaching consequences. Flush any cached
     # settings so they will be re-generated.
     flush_cache
-    mode
   end
 
   def parse_config(text, file = "text")
@@ -718,26 +734,26 @@ class Puppet::Settings
   end
 
   SETTING_TYPES = {
-      :string     => StringSetting,
-      :file       => FileSetting,
-      :directory  => DirectorySetting,
-      :file_or_directory => FileOrDirectorySetting,
-      :path       => PathSetting,
-      :boolean    => BooleanSetting,
-      :integer    => IntegerSetting,
-      :port       => PortSetting,
-      :terminus   => TerminusSetting,
-      :duration   => DurationSetting,
-      :ttl        => TTLSetting,
-      :array      => ArraySetting,
-      :enum       => EnumSetting,
-      :symbolic_enum   => SymbolicEnumSetting,
-      :priority   => PrioritySetting,
-      :autosign   => AutosignSetting,
-      :server_list => ServerListSetting,
-      :http_extra_headers => HttpExtraHeadersSetting,
-      :certificate_revocation => CertificateRevocationSetting,
-      :alias => AliasSetting
+    :string => StringSetting,
+    :file => FileSetting,
+    :directory => DirectorySetting,
+    :file_or_directory => FileOrDirectorySetting,
+    :path => PathSetting,
+    :boolean => BooleanSetting,
+    :integer => IntegerSetting,
+    :port => PortSetting,
+    :terminus => TerminusSetting,
+    :duration => DurationSetting,
+    :ttl => TTLSetting,
+    :array => ArraySetting,
+    :enum => EnumSetting,
+    :symbolic_enum => SymbolicEnumSetting,
+    :priority => PrioritySetting,
+    :autosign => AutosignSetting,
+    :server_list => ServerListSetting,
+    :http_extra_headers => HttpExtraHeadersSetting,
+    :certificate_revocation => CertificateRevocationSetting,
+    :alias => AliasSetting
   }
 
   # Create a new setting.  The value is passed in because it's used to determine
@@ -755,6 +771,7 @@ class Puppet::Settings
       unless klass
         raise ArgumentError, _("Invalid setting type '%{type}'") % { type: type }
       end
+
       hash.delete(:type)
     else
       # The only implicit typing we still do for settings is to fall back to "String" type if they didn't explicitly
@@ -774,7 +791,7 @@ class Puppet::Settings
   # Iterate across all of the objects in a given section.
   def persection(section)
     section = section.to_sym
-    self.each { |name, obj|
+    self.each { |_name, obj|
       if obj.section == section
         yield obj
       end
@@ -795,6 +812,7 @@ class Puppet::Settings
 
   def files
     return @files if @files
+
     @files = []
     [main_config_file, user_config_file].each do |path|
       if Puppet::FileSystem.exist?(path)
@@ -818,6 +836,7 @@ class Puppet::Settings
 
   def reuse
     return unless defined?(@used)
+
     new = @used
     @used = []
     self.use(*new)
@@ -1010,6 +1029,7 @@ class Puppet::Settings
       hash[:name] = name
       hash[:section] = section
       raise ArgumentError, _("Setting %{name} is already defined") % { name: name } if @config.include?(name)
+
       tryconfig = newsetting(hash)
       short = tryconfig.short
       if short
@@ -1017,6 +1037,7 @@ class Puppet::Settings
         if other
           raise ArgumentError, _("Setting %{name} is already using short name '%{short}'") % { name: other.name, short: short }
         end
+
         @shortnames[short] = tryconfig
       end
       @config[name] = tryconfig
@@ -1049,6 +1070,7 @@ class Puppet::Settings
       file = @config[key]
       next if file.value.nil?
       next unless (sections.nil? or sections.include?(file.section))
+
       resource = file.to_resource
       next unless resource
       next if catalog.resource(resource.ref)
@@ -1078,10 +1100,9 @@ own configured state, so they can be used to make Puppet a bit more self-managin
 The file format supports octothorpe-commented lines, but not partial-line comments.
 
 Generated on #{Time.now}.
-
 }.gsub(/^/, "# ")
 
-#         Add a section heading that matches our name.
+    #         Add a section heading that matches our name.
     str += "[#{preferred_run_mode}]\n"
     eachsection do |section|
       persection(section) do |obj|
@@ -1130,11 +1151,11 @@ Generated on #{Time.now}.
         if transaction.any_failed?
           report = transaction.report
           status_failures = report.resource_statuses.values.select { |r| r.failed? }
-          status_fail_msg = status_failures.
-            collect(&:events).
-            flatten.
-            select { |event| event.status == 'failure' }.
-            collect { |event| "#{event.resource}: #{event.message}" }.join("; ")
+          status_fail_msg = status_failures
+            .collect(&:events)
+            .flatten
+            .select { |event| event.status == 'failure' }
+            .collect { |event| "#{event.resource}: #{event.message}" }.join("; ")
 
           raise "Got #{status_failures.length} failure(s) while initializing: #{status_fail_msg}"
         end
@@ -1279,7 +1300,7 @@ Generated on #{Time.now}.
 
   def issue_deprecation_warning(setting, msg = nil)
     name = setting.name
-    ref = DEPRECATION_REFS.find { |params,reference| params.include?(name) }
+    ref = DEPRECATION_REFS.find { |params,_reference| params.include?(name) }
     ref = ref[1] if ref
     case
     when msg
@@ -1290,7 +1311,7 @@ Generated on #{Time.now}.
       message += " #{ref}"
       Puppet.deprecation_warning(message, "setting-#{name}")
     when setting.allowed_on_commandline?
-      #TRANSLATORS 'puppet.conf' is a file name and should not be translated
+      # TRANSLATORS 'puppet.conf' is a file name and should not be translated
       message = _("Setting %{name} is deprecated in puppet.conf.") % { name: name }
       message += " #{ref}"
       Puppet.deprecation_warning(message, "puppet-conf-setting-#{name}")
@@ -1334,7 +1355,7 @@ Generated on #{Time.now}.
     return if Puppet::Util::Platform.windows?
     return unless self[:mkusers]
 
-    @config.each do |name, setting|
+    @config.each do |_name, setting|
       next unless setting.respond_to?(:owner)
       next unless sections.nil? or sections.include?(setting.section)
 
@@ -1401,7 +1422,7 @@ Generated on #{Time.now}.
   #
   # @api public
   class ChainedValues
-    ENVIRONMENT_SETTING = "environment".freeze
+    ENVIRONMENT_SETTING = "environment"
     ENVIRONMENT_INTERPOLATION_ALLOWED = ['config_version'].freeze
 
     # @see Puppet::Settings.values
@@ -1429,9 +1450,9 @@ Generated on #{Time.now}.
         end
       end
 
-      setting  = @defaults[name]
+      setting = @defaults[name]
       if setting.respond_to?(:alias_name)
-        val  = lookup(setting.alias_name)
+        val = lookup(setting.alias_name)
         return val if val
       end
 
@@ -1494,24 +1515,24 @@ Generated on #{Time.now}.
         interpolated_value = value.gsub(/\$(\w+)|\$\{(\w+)\}/) do |expression|
           varname = $2 || $1
           interpolated_expression =
-          if varname != ENVIRONMENT_SETTING || ok_to_interpolate_environment(setting_name)
-            if varname == ENVIRONMENT_SETTING && @environment
-              @environment
-            elsif varname == "run_mode"
-              @mode
-            elsif !(pval = interpolate(varname.to_sym)).nil?
-              pval
+            if varname != ENVIRONMENT_SETTING || ok_to_interpolate_environment(setting_name)
+              if varname == ENVIRONMENT_SETTING && @environment
+                @environment
+              elsif varname == "run_mode"
+                @mode
+              elsif !(pval = interpolate(varname.to_sym)).nil?
+                pval
+              else
+                raise InterpolationError, _("Could not find value for %{expression}") % { expression: expression }
+              end
             else
-              raise InterpolationError, _("Could not find value for %{expression}") % { expression: expression }
+              failed_environment_interpolation = true
+              expression
             end
-          else
-            failed_environment_interpolation = true
-            expression
-          end
           interpolated_expression
         end
         if failed_environment_interpolation
-          #TRANSLATORS '$environment' is a Puppet specific variable and should not be translated
+          # TRANSLATORS '$environment' is a Puppet specific variable and should not be translated
           Puppet.warning(_("You cannot interpolate $environment within '%{setting_name}' when using directory environments.") % { setting_name: setting_name } +
                              ' ' + _("Its value will remain %{value}.") % { value: interpolated_value })
         end
@@ -1606,11 +1627,13 @@ Generated on #{Time.now}.
       if Puppet::Settings::EnvironmentConf::VALID_SETTINGS.include?(name) && conf
         return true
       end
+
       false
     end
 
     def lookup(name)
       return nil unless Puppet::Settings::EnvironmentConf::VALID_SETTINGS.include?(name)
+
       conf.send(name) if conf
     end
 
