@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Puppet
   Type.newtype(:exec) do
     include Puppet::Util::Execution
@@ -81,7 +83,7 @@ module Puppet
       @checks.keys
     end
 
-    newproperty(:returns, :array_matching => :all, :event => :executed_command) do |property|
+    newproperty(:returns, :array_matching => :all, :event => :executed_command) do |_property|
       include Puppet::Util::Execution
       munge do |value|
         value.to_s
@@ -94,6 +96,7 @@ module Puppet
       defaultto "0"
 
       attr_reader :output
+
       desc "The expected exit code(s).  An error will be returned if the
         executed command has some other exit code. Can be specified as an array
         of acceptable exit codes or a single value.
@@ -146,6 +149,7 @@ module Puppet
             debug("Exec try #{try+1}/#{tries}") if tries > 1
             @output, @status = provider.run(self.resource[:command])
             break if self.should.include?(@status.exitstatus.to_s)
+
             if try_sleep > 0 and tries > 1
               debug("Sleeping for #{try_sleep} seconds between tries")
               sleep try_sleep
@@ -352,9 +356,11 @@ module Puppet
           unless value =~ /^[\d]+$/
             raise ArgumentError, _("Tries must be an integer")
           end
+
           value = Integer(value)
         end
         raise ArgumentError, _("Tries must be an integer >= 1") if value < 1
+
         value
       end
 
@@ -369,16 +375,17 @@ module Puppet
           unless value =~ /^[-\d.]+$/
             raise ArgumentError, _("try_sleep must be a number")
           end
+
           value = Float(value)
         end
         raise ArgumentError, _("try_sleep cannot be a negative number") if value < 0
+
         value
       end
 
       defaultto 0
     end
 
-
     newcheck(:refreshonly) do
       desc <<-'EOT'
         The command should only be run as a
@@ -442,7 +449,7 @@ module Puppet
       # If the file exists, return false (i.e., don't run the command),
       # else return true
       def check(value)
-        #TRANSLATORS 'creates' is a parameter name and should not be translated
+        # TRANSLATORS 'creates' is a parameter name and should not be translated
         debug(_("Checking that 'creates' path '%{creates_path}' exists") % { creates_path: value })
         ! Puppet::FileSystem.exist?(value)
       end
@@ -592,13 +599,17 @@ module Puppet
       cmd = self[:command]
       cmd = cmd[0] if cmd.is_a? Array
 
-      cmd.scan(file_regex) { |str|
-        reqs << str
-      }
+      if cmd.is_a?(Puppet::Pops::Evaluator::DeferredValue)
+        self.debug("The 'command' parameter is deferred and cannot be autorequired")
+      else
+        cmd.scan(file_regex) { |str|
+          reqs << str
+        }
 
-      cmd.scan(/^"([^"]+)"/) { |str|
-        reqs << str
-      }
+        cmd.scan(/^"([^"]+)"/) { |str|
+          reqs << str
+        }
+      end
 
       [:onlyif, :unless].each { |param|
         tmp = self[param]
@@ -613,7 +624,11 @@ module Puppet
           # unqualified files, but, well, that's a bit more annoying
           # to do.
           line = line[0] if line.is_a? Array
-          reqs += line.scan(file_regex)
+          if line.is_a?(Puppet::Pops::Evaluator::DeferredValue)
+            self.debug("The '#{param}' parameter is deferred and cannot be autorequired")
+          else
+            reqs += line.scan(file_regex)
+          end
         end
       }
 
@@ -641,6 +656,7 @@ module Puppet
     def check_all_attributes(refreshing = false)
       self.class.checks.each { |check|
         next if refreshing and check == :refreshonly
+
         if @parameters.include?(check)
           val = @parameters[check].value
           val = [val] unless val.is_a? Array
@@ -686,6 +702,7 @@ module Puppet
     end
 
     private
+
     def set_sensitive_parameters(sensitive_parameters)
       # If any are sensitive, mark all as sensitive
       sensitive = false
