@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Puppet
   Puppet::Type.type(:file).newproperty(:ctime) do
     desc %q{A read-only state to check the file ctime. On most modern \*nix-like
@@ -10,10 +12,10 @@ module Puppet
       if stat
         current_value = stat.ctime
       end
-      current_value
+      current_value.to_s
     end
 
-    validate do |val|
+    validate do |_val|
       fail "ctime is read-only"
     end
   end
