@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Puppet
   Puppet::Type.type(:file).newproperty(:owner) do
     include Puppet::Util::Warnings
@@ -39,7 +41,7 @@ module Puppet
     end
 
     # We want to print names, not numbers
-    def is_to_s(currentvalue)
+    def is_to_s(currentvalue) # rubocop:disable Naming/PredicateName
       super(provider.uid2name(currentvalue) || currentvalue)
     end
 
